#
# spec file for package python-hatchling
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-hatchling
Version:        1.24.2
Release:        1.1
Summary:        Build backend used by Hatch
License:        MIT
URL:            https://hatch.pypa.io/latest/
Source0:        https://files.pythonhosted.org/packages/source/h/hatchling/hatchling-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module packaging >= 21.3}
BuildRequires:  %{python_module pathspec >= 0.10.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pluggy >= 1.0.0}
BuildRequires:  %{python_module tomli >= 1.2.2 if %python-base < 3.11}
BuildRequires:  %{python_module trove-classifiers}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-packaging >= 21.3
Requires:       python-pathspec >= 0.10.1
Requires:       python-pluggy >= 1.0.0
Requires:       python-trove-classifiers
Requires:       (python-tomli >= 1.2.2 if python-base < 3.11)
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This is the extensible, standards compliant build backend used by Hatch.

%prep
%autosetup -n hatchling-%{version} -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/hatchling

%check
# The tests provided in the tarball relies on internet access to run
# (git clone, pip install ...), so they cannot work on obs
# see tests/downstream/integrate.py for details

%post
%python_install_alternative hatchling

%postun
%python_uninstall_alternative hatchling

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/hatchling
%{python_sitelib}/hatchling-%{version}.dist-info
%python_alternative %{_bindir}/hatchling

%changelog
* Sun May 12 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.24.2:
  * Add .venv to the list of directories that cannot be traversed
  * Output from the core Application utility now writes to stderr
- Changes from version 1.24.1:
  * Maintain file permissions for shared-scripts
    option/shared_scripts build data of the wheel target
- Changes from version 1.24.0:
  * Add shared_data and shared_scripts build data for the wheel
    target
* Fri Apr  5 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.22.5:
  * Fix reading metadata from source distributions when fields are
    dynamic but not part of core metadata like entry points
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 1.22.4:
  * Only read source distribution metadata for fields that are
    explicitly defined as dynamic
* Wed Mar 20 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Tue Mar 19 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.22.3:
  * Fix the custom build hook when using dynamic dependencies
* Sun Mar 17 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to 1.22.2:
  * Fixed:
    + Fix regression when loading metadata from source
    distributions
    + Fix metadata hooks when building wheels from source
    distributions
- additional changes from version 1.22.1:
  * Fixed:
    + Update the default version of core metadata to 2.3
- additional changes from version 1.22.0:
  * Deprecated:
    + The app build target has been renamed to binary to reduce
    ambiguity with the name of an upcoming feature. The former
    name will still be usable for several minor releases.
  * Added:
    + Metadata for the wheel target now defaults to the PKG-INFO
    metadata within source distributions
    + Add dependencies method to the build hook interface so that
    hooks can themselves dynamically define dependencies
    + Update the default version of core metadata to 2.2
    + Update SPDX license information to version 3.23
    + Improve error message for when the default heuristics for
    wheel file inclusion fail
  * Fixed:
    + Properly support core metadata version 2.2
    + Remove editables as a direct dependency
    + Fix default wheel tag when the supported Python version
    declaration is strict
    + Load VCS ignore patterns first so that whitelisted patterns
    can be excluded by project configuration
    + Don't consider VCS ignore files that are outside of the VCS
    boundary
    + The sdist build target now gracefully ignores UNIX socket
    files
    + Begin ignoring certain files ubiquitously, like .DS_Store on
    macOS
- remove editables from the required packages
* Thu Jan 25 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to 1.21.1:
  * Fix loading of local plugins to account for newly released
    versions of a dependency
* Thu Dec 21 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 1.21.0:
  * Add parent context modifier for path fields
* Wed Dec 13 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 1.20.0:
  * Added:
    + Add bypass-selection option to the wheel build target to
    allow for empty (metadata-only) wheels
  * Fixed:
    + Fix regression in 1.19.1 that allowed exclude to count toward
    inclusion selection, thus bypassing the default inclusion
    selection heuristics
    + Fix writing optional dependency core metadata in situations
    where there are multiple environment markers
- additional changes from version 1.19.1:
  * Fixed:
    + Add better error message when the wheel build target cannot
    determine what to ship
    + Consider forced inclusion patterns and build-time artifacts
    as file selection since some build hooks generate the entire
    wheel contents without user configuration
- additional changes from version 1.19.0:
  * Changed:
    + An error will now be raised if a force-included path does not
    exist
    + An error will now be raised for the wheel build target if no
    file selection options are defined
  * Added:
    + Officially support Python 3.12
    + Allow using an empty string for the sources option to add a
    prefix to distribution paths
  * Fixed:
    + Properly handle non-zero version epoch for the standard
    version scheme
    + Fix the wheel build target for case insensitive file systems
    when the project metadata name does not match the directory
    name on disk
    + The app build target no longer has suppressed output
    + Prevent duplicate paths when projects require the sources
    option while build hooks overwrite included paths
    + Properly escape spaces for URI context formatting
* Wed Jun 21 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.18.0
  * Drop support for Python 3.7
  * Update the list of directories that are always excluded for
    builds
* Sat Jun  3 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.17.1:
  * Fix dev mode when the project has symlinks and file inclusion is
  defined with the packages or only-include options
  * Change the name of generated PTH files for dev mode so they come
  first lexicographically and therefore load first
* Sat May 13 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.17.0:
  * The app build target now embeds the project version in the name
    of binaries
* Thu May 11 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.16.1:
  * Fix determining the built executable path for the app build
    target option when using a local copy of PyApp when there is
    an explicit target triple set
- additional changes from version 1.16.0:
  * Add app build target option to build using a local copy of
    the PyApp repository
* Tue May  9 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.15.0:
  * Add app build target
* Mon Apr 24 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 1.14.1:
  * Fix internal archive root naming for the sdist target when
    strict-naming is disabled to match the file name in order to
    support the expectation of some frontends
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Mon Apr  3 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 1.14.0:
  * Added: Add trove-classifiers as a dependency
  * Fixed: Properly normalize metadata descriptions that contain
    line breaks
- requires python-trove-classifiers
* Thu Feb  9 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 1.13.0:
  * Update the set of known trove classifiers to version 2023.2.8
* Sun Jan  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.12.2:
  * Add macos-max-compat option to the wheel target that is enabled by default to
    support the latest version 22.0 of the packaging library
* Mon Jan  2 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.12.1:
  * Fixed:
    + Fix minor regression in the PEP 517/660 function signatures
    that was discovered by Fedora
- additional changes from version 1.12.0:
  * Added:
    + Improve readability of exceptions
    + Add extra_metadata build data to the wheel target
    + Retroactively support License-Expression core metadata
    starting at version 2.1
    + Add more type hints
    + Update the set of known trove classifiers to version
    2022.12.22
    + Update SPDX license information to version 3.19
    + Store Hatchling's metadata in pyproject.toml
  * Fixed:
    + Acknowledge the ARCHFLAGS environment variable on macOS for
    the wheel target when build hooks set the infer_tag build
    data to true
    + Fix dependency checking when encountering broken
    distributions
    + Remove unnecessary encoding declaration in the default
    template for the version build hook
- remove skip_python2: python >= 3.7 is already required
- drop python_module macro definition: provided by
  python-rpm-macros
* Thu Oct 20 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.11.1:
  * Fixed: Fix default file selection behavior of the wheel target
    when there is a single top-level module
* Sun Oct  9 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.11.0:
  * Added:
    + Add env version source to retrieve the version from an
    environment variable
    + Add validate-bump option to the standard version scheme
  * Fixed:
    + Use proper CSV formatting for the RECORD metadata file of the
    wheel target to avoid warnings during installation by pip if,
    for example, file names contain commas
    + Fix installations with pip for build hooks that modify
    runtime dependencies
    + Decreasing verbosity now has no affect on output that should
    always be displayed
* Fri Sep 23 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.10.0:
  * Added:
    + Add the following to the list of directories that cannot be
    traversed: __pypackages__, .hg, .hatch, .tox, .nox
    + Add deprecated option to allow ambiguous features
  * Fixed:
    + Improve tracking of dynamic metadata
    + Fix core metadata for entries in
    project.optional-dependencies that use direct references
* Tue Sep 13 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.9.0:
  * Changed:
    + File pattern matching now more closely resembles Git's
    behavior
  * Added:
    + Implement a minimal version of
    prepare_metadata_for_build_wheel and
    prepare_metadata_for_build_editable for non-frontend tools
    that only need to inspect a project's metadata
    + Add metadata command to view PEP 621 project metadata
    + Improve error messages for SPDX license errors
    + Retroactively support License-File for core metadata starting
    at version 2.1
    + Bump the minimum supported version of pathspec to 0.10.1
  * Fixed:
    + Allow the valid non-SPDX license values
    LicenseRef-Public-Domain and LicenseRef-Proprietary
    + Show the help text of the CLI when no subcommand is selected
- requires python-base to set the minimum python version, -devel is
  not needed
- requires pathspec >= 0.10.1
* Thu Aug 25 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.1:
  * Fixed:
    + Fix default file inclusion for wheel build targets when both
    the project name and package directory name are not
    normalized
* Thu Aug 18 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.0:
  * Added:
    + Add get_known_classifiers method to metadata hooks
  * Fixed:
    + Fix check for updating static versions with the version
    command when metadata hooks are in use
* Sat Aug 13 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.7.1:
  * Fixed:
    + Fix the value the relative_path attribute of included files,
    that some build plugins may use, when selecting explicit
    paths
* Sat Aug 13 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.7.0:
  * Added:
    + Add require-runtime-features option for builders and build
    hooks
    + Check for unknown trove classifiers
    + Update SPDX license information to version 3.18
  * Fixed:
    + Add better error message for wheel target dev mode
    installations that define path rewrites with the sources
    option
    + Note the allow-direct-references option in the relevant error
    messages
* Sat Jul 30 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.6.0:
  * Changed:
    + When no build targets are specified on the command line, now
    default to sdist and wheel targets rather than what happens
    to be defined in config
    + The code version source now only supports files with known
    extensions
    + Global build hooks now run before target-specific build hooks
    to better match expected behavior
  * Added:
    + The code version source now supports loading extension
    modules
    + Add search-paths option for the code version source
  * Fixed:
    + Fix removing sources using an empty string value in the
    mapping
    + The strict-naming option now also applies to the metadata
    directory of wheel targets
* Fri Jul 15 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.5.0:
  * Added:
    + Support the final draft of PEP 639
    + Add strict-naming option for sdist and wheel targets
  * Fixed: Project names are now stored in sdist and wheel target
    core metadata exactly as defined in pyproject.toml without
    normalization to allow control of how PyPI displays them
- require python 3.7 as minimum version to match upstream
  requirement
* Tue Jul  5 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.4.1:
  * Fixed:
    + Fix forced inclusion of important files like licenses for
    sdist targets when using the explicit selection options
    + Don't sort project URL metadata so that the rendered order
    on PyPI can be controlled
* Mon Jul  4 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.4.0:
  * Changed: The packages option uses the new only-include option
    to provide targeted inclusion, since that is desired most of
    the time
  * Added:
    + Support PEP 561 type hinting
    + Add version build hook
    + Add only-include option
    + The editable version of wheel targets now respects the
    force-include option by default
    + The force-include option now supports path rewriting with the
    sources option
    + The wheel target shared-data and extra-metadata options now
    respect file selection options
    + The wheel target now auto-detects single module layouts
    + Improve performance by never entering directories that are
    guaranteed to be undesirable like __pycache__ rather than
    excluding individual files within
    + Update SPDX license information to version 3.17
  * Fixed:
    + Don't write empty entry points file for wheel targets if
    there are no entry points defined
    + Allow metadata hooks to set the version in all cases
    + Prevent duplicate file entries from inclusion when using the
    force-include option
* Sun Jun 12 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.3.1:
  * Fixed: Better populate global variables for the code version
    source
- add a comment explaining why the tests are skipped in obs
  because they need internet access
* Thu May 26 2022 Benoît Monin <benoit.monin@gmx.fr>
- creation of the package with version 1.3.0
